%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%        RUN CODE OF THE PAPER             %%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Last Modification: 17 November  2008


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%    RUN SEVERAL ALGORITHMS FOR DIFFERENT   %%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%   SETTINGS OF THE GENERAL MODEL PROPOSAL  %%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%                                           %%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



Dataset='Arthritis';
prior_intrcp='Proper';
h=100;c=5;
N=3;w=5;
num_iter=500000;num_burn=100000;num_thin=5;num=(num_iter-num_burn)/num_thin;
P=0;%Set the parameter of the model proposal. It takes values from 0 to 1.

%Change the directory according to the folder you save the
%Suplementary_Material. In the case you want to run the code from another directory use the
%command addpath.
cd 'C:\Supplementary_Material'

cd 'RJ_Samplers'
addpath '..\Matlib'

%Load the Dataset in the case you use a provided dataset.
load (['..\Data\',Dataset,'.mat'])

if isequal(Dataset,'Leukemia')

    target=(target==0)*0+(target==1)*0+(target==2)*1;%Make two classes.

end

%Preprocess the design matrix using the PreProcess_Genes function in the case you are using your own dataset.
%The following specific format of the function is only centering the columns of the design matrix.
%X=PreProcess_Genes(1:length(target),X,target,[0 0 0 0 1]);

%Holmes and Held algorithm.
alg=1;

[prob_inclusion,ESS,Beta,L,acceptance]=Holmes_Held([target X],prior_intrcp,h,c,N,P,w,num_iter,num_burn,num_thin);



%Automatic generic sampler with Laplace approximation.
alg=2

[prob_inclusion,ESS,Beta,L,acceptance]=AG_LA([target X],prior_intrcp,h,c,N,P,w,num_iter,num_burn,num_thin);



%Automatic generic sampler with Iterated Weighted Least Square approximation.
alg=3

[prob_inclusion,ESS,Beta,L,acceptance]=AG_IWLS([target X],prior_intrcp,h,c,N,P,w,num_iter,num_burn,num_thin);



%Zeroth Order algorithm.
alg=4

[prob_inclusion,ESS,Beta,L,acceptance]=Zeroth_Order([target X],prior_intrcp,h,c,N,P,w,num_iter,num_burn,num_thin);



%First Order algorithm.
alg=5

[prob_inclusion,ESS,Beta,L,acceptance]=First_Order([target X],prior_intrcp,h,c,N,P,w,num_iter,num_burn,num_thin);



%Conditional Maximisation algorithm.
alg=6

[prob_inclusion,ESS,Beta,L,acceptance]=Cond_Max([target X],prior_intrcp,h,c,N,P,w,num_iter,num_burn,num_thin);


%Second Order algorithm.
N=1;
alg=7

[prob_inclusion,ESS,Beta,L,acceptance]=Second_Order([target X],prior_intrcp,h,c,N,P,w,num_iter,num_burn,num_thin);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%       PLOT THE POSTERIOR GENE INCLUSION PROBABILITIES                %%%
%%                                                                      %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


plot(prob_inclusion,'-')
title(Dataset,'Fontsize',12)
xlim([0 length(X)])
xlabel('Gene ID','Fontsize',12)
ylabel('Posterior Inclusion Frequency','Fontsize',12)




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  CALCULATE THE POSTERIOR MEAN OF THE REGRESSION COEFFICIENTS       %%%%%
%%                                                                    %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[n p]=size(X);
mean_beta=zeros(1,1+p);%The first component corresponds to the intercept.

for j=1:length(Beta)

    mean_beta([1 L{j}])=mean_beta([1 L{j}])+Beta{j}/length(Beta);

end

%mean_beta=mean_beta/length(Beta)

